#!/usr/bin/env node

const { Octokit } = require('octokit');
const { createOAuthDeviceAuth } = require("@octokit/auth-oauth-device");
const { question } = require("readline-sync");

const gitAuth = question("GitHub token :");
const octokit = new Octokit({
  auth: gitAuth,
});

const prompts = require('prompts');

const questions = [
    {
      type: 'text',
      name: 'username',
      message: 'What is your GitHub username?'
    },
    {
      type: 'text',
      name: 'repository',
      message: 'Repository name: '
    },
    {
      type: 'text',
      name: 'projectName',
      message: 'Project name:',
    },
    {
        type: 'select',
        name: 'template',
        message: 'Choose a project template!',
        choices:[
        {title:'Basic Kanban', value: 'Basic Kanban'},
        {title:'Automated Kanban', value: 'Automated Kanban'},
        {title:'Bugs triage', value: 'Bugs triage'},
        ],
    }
  ];
// prompting for values
async function enterValues(){
    const response = await prompts(questions);
    
    console.log(response.username);
  run(response.username,response.repository,response.projectName,response.template);
}

async function run(username,repository,projectName,template){
  try{
    const { data: project } = await octokit.request('POST /repos/{owner}/{repo}/projects', {
      owner: username,
      repo: repository,
      name: projectName,
      mediaType: {
        previews: [
          'inertia'
        ]
      }
    });

    console.log("Created project "+ project.name);
    console.log("Template : "+template);

    if (template == 'Automated Kanban'){
        auto_kanban(project.id);
    }

  }    
  catch(err){
    console.error(err);
  }
}

async function auto_kanban(projectID){
    const cols = ['To Do','In progress','Review in progress','Reviewer approved','Done']
    console.log('Project ID: '+ projectID)
    for(const col in cols){
        const { data: column } = await octokit.request('POST /projects/{project_id}/columns', {
            project_id: projectID,
            name: cols[col],
            mediaType: {
              previews: [
                'inertia'
              ]
            }
          });
        
        console.log('Added column '+column.name);
    }
}

enterValues();


